@@ -35,6 +35,8 @@
 #include <QDebug>
 #include <QFileInfo>
 
+#include <DWidgetUtil>
+
 using namespace Dtk::Widget;
 
 namespace {
@@ -165,8 +167,6 @@ void CommandLine::viewImage(const QString &path, const QStringList &paths)
         m_mainWindow = new MainWindow(false);
     }
 
-    m_mainWindow->setWindowRadius(18);
-    m_mainWindow->setBorderWidth(0);
     m_mainWindow->show();
 
     // Load image after all UI elements has been init
@@ -209,8 +209,12 @@ bool CommandLine::processOption()
 
     QObject::connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::paletteTypeChanged,
     [](DGuiApplicationHelper::ColorType type) {
-        Q_UNUSED(type);
-
+        //更改主题颜色的信号,图片跟着变化
+        if (type == DGuiApplicationHelper::DarkType) {
+            dApp->viewerTheme->setCurrentTheme(ViewerThemeManager::Dark);
+        } else if (type == DGuiApplicationHelper::LightType) {
+            dApp->viewerTheme->setCurrentTheme(ViewerThemeManager::Light);
+        }
     });
 
     QStringList names = m_cmdParser.optionNames();
