@@ -31,6 +31,7 @@
 #include <dgiovolumemanager.h>
 #include <DDialog>
 #include <DFontSizeManager>
+#include <DStackedWidget>
 #include <QDir>
 #include <QScreen>
 #include <QShortcut>
@@ -38,6 +39,7 @@
 #include <QJsonParseError>
 #include <QJsonArray>
 #include <QShortcut>
+#include <QMenu>
 
 #include "utils/baseutils.h"
 #include "../service/dbusimageview_adaptor.h"
@@ -50,7 +52,7 @@
 namespace {
 
 const int MAINWIDGET_MINIMUN_HEIGHT = 335;
-const int MAINWIDGET_MINIMUN_WIDTH = 630;
+const int MAINWIDGET_MINIMUN_WIDTH = 730;//增加了ocr，最小宽度为630到现在730
 const QString SETTINGS_GROUP = "MAINWINDOW";
 const QString SETTINGS_WINSIZE_W_KEY = "WindowWidth";
 const QString SETTINGS_WINSIZE_H_KEY = "WindowHeight";
@@ -89,6 +91,7 @@ MainWindow::MainWindow(bool manager, QWidget *parent)
     m_pCenterWidget->setAccessibleName(CENTER_WIDGET);
 #endif
     if (titlebar()) {
+        titlebar()->setMenu(new QMenu(this));
         titlebar()->setFixedHeight(50);
         titlebar()->setTitle("");
         titlebar()->setIcon(QIcon::fromTheme("deepin-image-viewer"));
@@ -108,6 +111,15 @@ MainWindow::MainWindow(bool manager, QWidget *parent)
             }
         });
     }
+    QList<DTitlebar *>titlebar = findChildren <DTitlebar *>();
+    for (DTitlebar *bar : titlebar) {
+        if (bar) {
+            bar->setFocusPolicy(Qt::ClickFocus);
+        }
+    }
+    connect(dApp, &Application::TabkeyPress, this, [ = ](QObject * obj) {
+        initAllViewTabKeyOrder(obj);
+    }, Qt::DirectConnection);
 
     setCentralWidget(m_pCenterWidget);
     moveFirstWindow();
@@ -203,21 +215,23 @@ void MainWindow::initdbus()
 
 void MainWindow::initConnection()
 {
-    QShortcut *scViewShortcut = new QShortcut(QKeySequence("Ctrl+Shift+/"), this);
-    scViewShortcut->setObjectName(SC_VIEW_SHORTCUT);
-    // connect(scE, SIGNAL(activated()), dApp, SLOT(quit()));
-    connect(scViewShortcut, &QShortcut::activated, this, [ = ] {
-        qDebug() << "receive Ctrl+Shift+/";
-        QRect rect = window()->geometry();
-        QPoint pos(rect.x() + rect.width() / 2, rect.y() + rect.height() / 2);
-        Shortcut sc;
-        QStringList shortcutString;
-        QString param1 = "-j=" + sc.toStr();
-        QString param2 = "-p=" + QString::number(pos.x()) + "," + QString::number(pos.y());
-        shortcutString << "-b" << param1 << param2;
-        qDebug() << shortcutString;
-        QProcess::startDetached("deepin-shortcut-viewer", shortcutString);
-    });
+    if (!dApp->isPanelDev()) {
+        QShortcut *scViewShortcut = new QShortcut(QKeySequence("Ctrl+Shift+/"), this);
+        scViewShortcut->setObjectName(SC_VIEW_SHORTCUT);
+        // connect(scE, SIGNAL(activated()), dApp, SLOT(quit()));
+        connect(scViewShortcut, &QShortcut::activated, this, [ = ] {
+            qDebug() << "receive Ctrl+Shift+/";
+            QRect rect = window()->geometry();
+            QPoint pos(rect.x() + rect.width() / 2, rect.y() + rect.height() / 2);
+            Shortcut sc;
+            QStringList shortcutString;
+            QString param1 = "-j=" + sc.toStr();
+            QString param2 = "-p=" + QString::number(pos.x()) + "," + QString::number(pos.y());
+            shortcutString << "-b" << param1 << param2;
+            qDebug() << shortcutString;
+            QProcess::startDetached("deepin-shortcut-viewer", shortcutString);
+        });
+    }
     connect(m_slidePanel, SIGNAL(sigloadSlideshowpath(bool)), m_mainWidget, SIGNAL(mainwgtloadslideshowpath(bool)));
 //    connect(m_mainWidget, SIGNAL(sigmaindgtslideshowpath(bool, DBImgInfoList)), m_slidePanel, SLOT(Receiveslideshowpathlst(bool, DBImgInfoList)));
     connect(this, SIGNAL(sigExitFull()), m_mainWidget, SIGNAL(sigExitFullScreen()));
@@ -246,6 +260,7 @@ void MainWindow::initConnection()
         //  emit dApp->signalM->hideTopToolbar(false);
 
     });
+
 }
 
 void MainWindow::moveFirstWindow()
@@ -320,6 +335,115 @@ void MainWindow::onThemeChanged(ViewerThemeManager::AppTheme theme)
     }
 }
 
+void MainWindow::initAllViewTabKeyOrder(QObject *obj)
+{
+    Q_UNUSED(obj);
+    DStackedWidget *stackwidget = findChild<DStackedWidget *>(VIEW_PANEL_STACK);
+    if (stackwidget) {
+        switch (stackwidget->currentIndex()) {
+        case 1: {
+            initEmptyTabOrder();
+            break;
+        }
+        default: {
+            initNormalPicTabOrder();
+            break;
+        }
+        }
+    }
+}
+
+void MainWindow::initEmptyTabOrder()
+{
+    titlebar()->show();
+    m_emptyTabOrder.clear();
+    QWidget *openBtn = findChild<QWidget *>(OPEN_IMAGE);
+    QWidget *optionButton =  titlebar()->findChild<QWidget *>("DTitlebarDWindowOptionButton");
+    QWidget *minButton =  titlebar()->findChild<QWidget *>("DTitlebarDWindowMinButton");
+    QWidget *maxButton =  titlebar()->findChild<QWidget *>("DTitlebarDWindowMaxButton");
+    QWidget *closeButton =  titlebar()->findChild<QWidget *>("DTitlebarDWindowCloseButton");
+    if (openBtn && optionButton && minButton && maxButton && closeButton) {
+        m_emptyTabOrder.insert(0, openBtn);
+        m_emptyTabOrder.insert(1, optionButton);
+        m_emptyTabOrder.insert(2, minButton);
+        m_emptyTabOrder.insert(3, maxButton);
+        m_emptyTabOrder.insert(4, closeButton);
+    }
+    for (int idx = 0; idx < m_emptyTabOrder.count() - 1; idx++) {
+        this->setTabOrder(m_emptyTabOrder.at(idx), m_emptyTabOrder.at(idx + 1));
+    }
+}
+
+void MainWindow::initNormalPicTabOrder()
+{
+    titlebar()->hide();
+    QWidget *view = findChild<QWidget *>(IMAGE_VIEW);
+    if (view) {
+        view->setFocusPolicy(Qt::ClickFocus);
+    }
+    m_NormalPicTabOrder.clear();
+    QWidget *preBtn = findChild<QWidget *>(PRE_BUTTON);
+    QWidget *nextBtn = findChild<QWidget *>(NEXT_BUTTON);
+    QWidget *adaptBtn = findChild<QWidget *>(ADAPT_BUTTON);
+    QWidget *adaptscreenBtn = findChild<QWidget *>(ADAPT_SCREEN_BUTTON);
+    QWidget *clockrightBtn = findChild<QWidget *>(COUNTER_CLOCKWISE_ROTATION);
+    QWidget *clockleftBtn = findChild<QWidget *>(CLOCKWISE_ROTATION);
+    QWidget *trashBtn = findChild<QWidget *>(TRASH_BUTTON);
+    QWidget *optionButton =  titlebar()->findChild<QWidget *>("DTitlebarDWindowOptionButton");
+    QWidget *minButton =  titlebar()->findChild<QWidget *>("DTitlebarDWindowMinButton");
+    QWidget *maxButton =  titlebar()->findChild<QWidget *>("DTitlebarDWindowMaxButton");
+    QWidget *closeButton =  titlebar()->findChild<QWidget *>("DTitlebarDWindowCloseButton");
+    QList<TopToolbar *>titlebar1 = findChildren <TopToolbar *>(TOP_TOOL_BAR);
+
+    for (TopToolbar *bar : titlebar1) {
+        if (bar) {
+            optionButton =  bar->findChild<QWidget *>("DTitlebarDWindowOptionButton");
+            minButton =  bar->findChild<QWidget *>("DTitlebarDWindowMinButton");
+            maxButton =  bar->findChild<QWidget *>("DTitlebarDWindowMaxButton");
+            closeButton =  bar->findChild<QWidget *>("DTitlebarDWindowCloseButton");
+
+        }
+    }
+
+    m_NormalPicTabOrder.insert(0, preBtn);
+    m_NormalPicTabOrder.insert(1, nextBtn);
+    m_NormalPicTabOrder.insert(2, adaptBtn);
+    m_NormalPicTabOrder.insert(3, adaptscreenBtn);
+    m_NormalPicTabOrder.insert(4, clockrightBtn);
+    m_NormalPicTabOrder.insert(5, clockleftBtn);
+    m_NormalPicTabOrder.insert(6, trashBtn);
+    QWidget    *upBtn = findChild<QWidget *>(MOREPIC_UP_BUTTON);
+    QWidget    *downBtn = findChild<QWidget *>(MOREPIC_DOWN_BUTTON);
+    if (upBtn && downBtn) {
+        m_NormalPicTabOrder.push_back(upBtn);
+        m_NormalPicTabOrder.push_back(downBtn);
+    }
+    if (!window()->isFullScreen()) {
+        m_NormalPicTabOrder.push_back(optionButton);
+        m_NormalPicTabOrder.push_back(minButton);
+        m_NormalPicTabOrder.push_back(maxButton);
+        m_NormalPicTabOrder.push_back(closeButton);
+    } else {
+        optionButton->setFocusPolicy(Qt::ClickFocus);
+        minButton->setFocusPolicy(Qt::ClickFocus);
+        maxButton->setFocusPolicy(Qt::ClickFocus);
+        closeButton->setFocusPolicy(Qt::ClickFocus);
+
+        QList<QWidget *>fullBtnlist = findChildren<QWidget *>("DTitlebarDWindowQuitFullscreenButton");
+        for (QWidget *fullBtn : fullBtnlist) {
+            if (fullBtn) {
+                fullBtn->setFocusPolicy(Qt::ClickFocus);
+            }
+        }
+
+    }
+
+    for (int idx = 0; idx < m_NormalPicTabOrder.count() - 1; idx++) {
+        this->setTabOrder(m_NormalPicTabOrder.at(idx), m_NormalPicTabOrder.at(idx + 1));
+    }
+
+}
+
 void MainWindow::resizeEvent(QResizeEvent *e)
 {
     if (!isMaximized() && m_mainWidget->isVisible() && !window()->isFullScreen() &&
@@ -423,25 +547,11 @@ void MainWindow::OpenImage(const QString &path)
         info.inDatabase = false;
 #endif
         info.lastPanel = nullptr;
-        info.path = spath;
+        info.path = path;
         info.paths = pathlist;
 
         emit dApp->signalM->viewImage(info);
-
-        //20210111lmh平板可以多次改变，正常模式不需要
-        if (dApp->isPanelDev()) {
-            m_flag = false;
-        } else {
-            m_flag = true;
-        }
+        //dbus接口修复,可以通过dbus接口打开图片
+        m_flag = false;
     }
-    //新的图片打开需要激活窗口20210113
-    activateWindow();
-
-//    qint64 temptime = m_currenttime.secsTo(stime);
-//    if (temptime < 0) return;
-//    if (temptime < 2) {
-
-
-//    }
 }
