@@ -61,12 +61,14 @@ private:
     QVector<QString> loop_paths;
     QMutex queueMutex;
     bool loop_order;
-    char m_padding[3]; //填充占位,使数据结构内存对齐
+    char m_padding[3] = {'0', '0', '0'}; //填充占位,使数据结构内存对齐
     int loop_pindex;
 };
 
-class ImageAnimationPrivate: public QWidget
+class ImageAnimationPrivate : public QWidget
 {
+    Q_OBJECT
+
 public:
     enum AnimationType {
         FadeEffect = 0,             //图像1渐渐变淡,图像2渐渐显现
@@ -97,10 +99,6 @@ protected:
     void flipRightToLeft(QPainter *painter, const QRect &rect, float factor, const QPixmap &pixmap1, const QPixmap &pixmap2);
     void outsideToInside(QPainter *painter, const QRect &rect, float factor, const QPixmap &pixmap1, const QPixmap &pixmap2);
     void moveLeftToRightEffect(QPainter *painter, const QRect &rect, float factor, const QPixmap &pixmap1, const QPixmap &pixmap2);
-    void moveRightToLeftEffect(QPainter *painter, const QRect &rect, float factor, const QPixmap &pixmap1, const QPixmap &pixmap2);
-    void moveBottomToUpEffect(QPainter *painter, const QRect &rect, float factor, const QPixmap &pixmap1, const QPixmap &pixmap2);
-    void moveUpToBottomEffect(QPainter *painter, const QRect &rect, float factor, const QPixmap &pixmap1, const QPixmap &pixmap2);
-    void moveBottomToLeftUpEffect(QPainter *painter, const QRect &rect, float factor, const QPixmap &pixmap1, const QPixmap &pixmap2);
 
     //新增获取当前图片路径
     const QString getCurrentPath();
@@ -205,7 +203,7 @@ private:
 //    }
 
 private:
-    char m_padding2[3];                 //填充占位,使数据结构内存对齐
+    char m_padding2[3] = {'0', '0', '0'};;              //填充占位,使数据结构内存对齐
     QSharedPointer<LoopQueue> queue;
     QPointer<QTimer> m_singleanimationTimer;
     QPointer<QTimer> m_continuousanimationTimer;
@@ -371,18 +369,6 @@ void ImageAnimationPrivate::effectPainter(QPainter *painter, const QRect &rect)
     case 4:
         moveLeftToRightEffect(painter, rect, m_factor, m_pixmap1, m_pixmap2);
         break;
-    case 5:
-        moveRightToLeftEffect(painter, rect, m_factor, m_pixmap1, m_pixmap2);
-        break;
-    case 6:
-        moveBottomToUpEffect(painter, rect, m_factor, m_pixmap1, m_pixmap2);
-        break;
-    case 7:
-        moveUpToBottomEffect(painter, rect, m_factor, m_pixmap1, m_pixmap2);
-        break;
-    case 8:
-        moveBottomToLeftUpEffect(painter, rect, m_factor, m_pixmap1, m_pixmap2);
-        break;
     }
     painter->end();
 }
@@ -561,42 +547,6 @@ void ImageAnimationPrivate::moveLeftToRightEffect(QPainter *painter, const QRect
     painter->drawPixmap(x, y, pixmap2);
 }
 
-void ImageAnimationPrivate::moveRightToLeftEffect(QPainter *painter, const QRect &rect, float factor, const QPixmap &pixmap1, const QPixmap &pixmap2)
-{
-    Q_UNUSED(painter);
-    Q_UNUSED(rect);
-    Q_UNUSED(factor);
-    Q_UNUSED(pixmap1);
-    Q_UNUSED(pixmap2);
-}
-
-void ImageAnimationPrivate::moveBottomToUpEffect(QPainter *painter, const QRect &rect, float factor, const QPixmap &pixmap1, const QPixmap &pixmap2)
-{
-    Q_UNUSED(painter);
-    Q_UNUSED(rect);
-    Q_UNUSED(factor);
-    Q_UNUSED(pixmap1);
-    Q_UNUSED(pixmap2);
-}
-
-void ImageAnimationPrivate::moveUpToBottomEffect(QPainter *painter, const QRect &rect, float factor, const QPixmap &pixmap1, const QPixmap &pixmap2)
-{
-    Q_UNUSED(painter);
-    Q_UNUSED(rect);
-    Q_UNUSED(factor);
-    Q_UNUSED(pixmap1);
-    Q_UNUSED(pixmap2);
-}
-
-void ImageAnimationPrivate::moveBottomToLeftUpEffect(QPainter *painter, const QRect &rect, float factor, const QPixmap &pixmap1, const QPixmap &pixmap2)
-{
-    Q_UNUSED(painter);
-    Q_UNUSED(rect);
-    Q_UNUSED(factor);
-    Q_UNUSED(pixmap1);
-    Q_UNUSED(pixmap2);
-}
-
 const QString ImageAnimationPrivate::getCurrentPath()
 {
     return queue->current();
@@ -614,7 +564,7 @@ void ImageAnimationPrivate::startAnimation()
     qsrand(static_cast<uint>(QTime(0, 0, 0).secsTo(QTime::currentTime())));
     m_animationType = static_cast<AnimationType>(qrand() % (3));
     if (!m_continuousanimationTimer) {
-        m_continuousanimationTimer = new QTimer();
+        m_continuousanimationTimer = new QTimer(this);
         m_factor = 0.0f;
         m_funval = 0.0f;
         connect(m_continuousanimationTimer, &QTimer::timeout, this, &ImageAnimationPrivate::onContinuousAnimationTimer);
@@ -650,7 +600,7 @@ void ImageAnimationPrivate::startSinglePreAnimation()
 void ImageAnimationPrivate::startStatic()
 {
     if (!m_staticTimer) {
-        m_staticTimer = new QTimer;
+        m_staticTimer = new QTimer(this);
         m_staticTimer->setSingleShot(true);
         connect(m_staticTimer, &QTimer::timeout, this, &ImageAnimationPrivate::onStaticTimer);
     }
@@ -698,7 +648,8 @@ void ImageAnimationPrivate::setImage1(const QString &imageName1_bar)
     m_imageName1 = imageName1_bar;
     QImage tImg;
     QString errMsg;
-    UnionImage_NameSpace::loadStaticImageFromFile(imageName1_bar, tImg, errMsg);
+    QSize realSize;
+    UnionImage_NameSpace::loadStaticImageFromFile(imageName1_bar, tImg, realSize, errMsg);
     QPixmap p1 = QPixmap::fromImage(tImg);
     int beginX = 0, beginY = 0;
     // 多屏显示问题，定位当前屏幕
@@ -744,7 +695,8 @@ void ImageAnimationPrivate::setImage2(const QString &imageName2_bar)
     int beginX = 0, beginY = 0;
     QImage tImg;
     QString errMsg;
-    UnionImage_NameSpace::loadStaticImageFromFile(imageName2_bar, tImg, errMsg);
+    QSize realSize;
+    UnionImage_NameSpace::loadStaticImageFromFile(imageName2_bar, tImg, realSize, errMsg);
     QPixmap p2 = QPixmap::fromImage(tImg);
     // 双屏下或者多屏下
     int screenId = dApp->m_app->desktop()->screenNumber(q_ptr);
@@ -913,3 +865,5 @@ void ImageAnimation::setPaintTarget(PaintTarget target)
 {
     current_target = target;
 }
+
+#include "imageanimation.moc"
