@@ -62,17 +62,17 @@ const QString LOCMAP_NOT_SELECTED_DAMAGED_DARK = ":/dark/images/picture_damaged_
 const QString LOCMAP_SELECTED_DAMAGED_LIGHT = ":/light/images/picture_damaged_58.svg";
 const QString LOCMAP_NOT_SELECTED_DAMAGED_LIGHT = ":/light/images/picture_damaged.svg";
 
-const int TOOLBAR_MINIMUN_WIDTH = 610 - 3;
-const int TOOLBAR_JUSTONE_WIDTH = 310;
+const int TOOLBAR_MINIMUN_WIDTH = 680 - 3;//610->680
+const int TOOLBAR_JUSTONE_WIDTH = 350;
 const int RT_SPACING = 20 + 5;
 const int TOOLBAR_HEIGHT = 60;
 
-const int TOOLBAR_DVALUE = 114 + 8;
+const int TOOLBAR_DVALUE = 124 + 8;
 
 const int THUMBNAIL_WIDTH = 32;
 const int THUMBNAIL_ADD_WIDTH = 32;
 const int THUMBNAIL_LIST_ADJUST = 9 + 5;
-const int THUMBNAIL_VIEW_DVALUE = 496 + 10;
+const int THUMBNAIL_VIEW_DVALUE = 550 + 10;//ocr增加后从496到550
 
 const unsigned int IMAGE_TYPE_JEPG = 0xFFD8FF;
 const unsigned int IMAGE_TYPE_JPG1 = 0xFFD8FFE0;
@@ -630,6 +630,7 @@ void ImageItem::paintEvent(QPaintEvent *event)
         QPen(DGuiApplicationHelper::instance()->applicationPalette().frameBorder().color(), 1));
     painter.drawRoundedRect(pixmapRect, 4, 4);
     painter.restore();
+
 }
 
 TTBContent::TTBContent(bool inDB, DBImgInfoList m_infos, bool flag, QWidget *parent)
@@ -683,7 +684,11 @@ void TTBContent::initBtn()
     //默认只有一张图片先不显示
     if (dApp->IsOnlyOnePic()) {
         m_preButton->setVisible(false);
+        qDebug() << "686 initBtn";
+    } else {
+        m_preButton->setVisible(true);
     }
+
     // nextButton
     m_nextButton = new DIconButton(this);
     m_nextButton->setObjectName("NextButton");
@@ -694,6 +699,8 @@ void TTBContent::initBtn()
     //默认只有一张图片先不显示
     if (dApp->IsOnlyOnePic()) {
         m_nextButton->setVisible(false);
+    } else {
+        m_nextButton->setVisible(true);
     }
 
     m_preButton_spc = new DWidget;
@@ -731,6 +738,16 @@ void TTBContent::initBtn()
     hb->addWidget(m_adaptScreenBtn);
     hb->addSpacing(ICON_SPACING);
 
+    // ocr
+    m_ocrBtn = new DIconButton(this);
+    m_ocrBtn->setFixedSize(ICON_SIZE);
+    m_ocrBtn->setObjectName("OcrBtn");
+    m_ocrBtn->setIcon(QIcon::fromTheme("dcc_ocr"));
+    m_ocrBtn->setIconSize(QSize(36, 36));
+    m_ocrBtn->setToolTip(tr("Extract text"));
+    hb->addWidget(m_ocrBtn);
+    hb->addSpacing(ICON_SPACING);
+
     // rotateLBtn
     m_rotateLBtn = new DIconButton(this);
     m_rotateLBtn->setFixedSize(ICON_SIZE);
@@ -766,6 +783,7 @@ void TTBContent::initBtn()
                        qMax(m_windowWidth - RT_SPACING, TOOLBAR_MINIMUN_WIDTH)) -
                   THUMBNAIL_VIEW_DVALUE + THUMBNAIL_LIST_ADJUST,
                   TOOLBAR_HEIGHT));
+
     }
 
     m_imgList->setEnabled(true);
@@ -916,6 +934,7 @@ void TTBContent::toolbarSigConnection()
         }
     });
 
+    connect(m_ocrBtn, &DIconButton::clicked, this, &TTBContent::ocrCurrentPicture);
     connect(m_adaptScreenBtn, &DIconButton::clicked, this, [ = ] {
         emit resetTransform(true);
         setAdaptButtonChecked(false);
@@ -1190,8 +1209,12 @@ void TTBContent::disableDelAct(bool bFlags)
 {
     //对于只读权限的图片，切换图片后等待5秒左右，删除按钮会激活并删除只读图片
     QFileInfo fileinfo(m_strCurImagePath);
-    if (fileinfo.isReadable() && fileinfo.isWritable() && bFlags)
+    //新增保险箱的判断，保险箱无法删除
+
+    if ((fileinfo.isReadable() && fileinfo.isWritable() && bFlags) || utils::image::isCanRemove(m_strCurImagePath)) {
         m_trashBtn->setEnabled(bFlags);
+    }
+
 }
 
 void TTBContent::recvLoadAddInfos(DBImgInfoList newInfos, bool bFlags)
@@ -1241,52 +1264,10 @@ void TTBContent::reloadItems(DBImgInfoList &inputInfos, QString strCurPath)
             /*LMH0727*/
             // imageItem->setObjectName(QString("%1").arg(m_totalImageItem++));
             m_imglayout->addWidget(imageItem);
-            connect(imageItem, &ImageItem::imageMoveclicked, this,
-            [ = ](QString path) {
-                m_bMoving = false;
-                if (dApp->m_bMove) {
-                    m_lastIndex = m_nowIndex;
-                    QList <ImageItem *>labelList = m_imgList->findChildren<ImageItem *>(path);
-                    if (labelList.size() > 0) {
-                        ImageItem *img = labelList.at(0);
-                        if (nullptr != img) {
-                            img->setIndexNow(m_nowIndex);
-                            labelList.at(0)->setFixedSize(QSize(58, 58));
-                            labelList.at(0)->resize(QSize(58, 58));
-                            QPixmap pix = img->getPixmap();
-                            m_nowIndex = img->getIndex();
-                            emit showvaguepixmap(pix, labelList.at(0)->getPath());
-                            emit sigsetcurrent(labelList.at(0)->getPath());
-                        }
-                    }
-                    if (m_lastIndex > -1) {
-                        QList <ImageItem *>lastlabelList = m_imgList->findChildren<ImageItem *>(/*QString("%1").arg(m_lastIndex)*/);
-                        if (lastlabelList.isEmpty()) {
-                        } else {
-                            for (int i = 0; i < lastlabelList.size(); i++) {
-                                if (lastlabelList.at(i)->getIndex() != m_nowIndex) {
-                                    lastlabelList.at(i)->setFixedSize(QSize(32, 40));
-                                    lastlabelList.at(i)->resize(QSize(32, 40));
-                                    lastlabelList.at(i)->setIndexNow(m_nowIndex);
-                                }
-                            }
-                        }
+            connect(imageItem, &ImageItem::imageMoveclicked, this, &TTBContent::slotMovePress);
 
-                    }
+            connect(imageItem, &ImageItem::imageItemclicked, this, &TTBContent::slotClickPress);
 
-                }
-            });
-            connect(imageItem, &ImageItem::imageItemclicked, this,
-            [ = ](int index, int indexNow, bool iRet) {
-                m_bMoving = true;
-
-                m_nowIndex = index;
-//                emit imageClicked(index, (index - indexNow));
-                emit imageMoveEnded(index, (index - indexNow), iRet);
-                m_lastIndex = m_nowIndex;
-//                onResize();
-//                m_imgList->adjustSize();
-            });
 
         }
         if (strCurPath == info.filePath) {
@@ -1484,6 +1465,7 @@ void TTBContent::setBtnAttribute(const QString strPath)
         m_trashBtn->setEnabled(false);
         m_adaptImageBtn->setEnabled(false);
         m_adaptScreenBtn->setEnabled(false);
+        m_ocrBtn->setEnabled(false);
         return;
     }
     if (!utils::image::imageSupportRead(strPath)) {
@@ -1491,12 +1473,13 @@ void TTBContent::setBtnAttribute(const QString strPath)
         m_rotateRBtn->setEnabled(false);
         m_adaptImageBtn->setEnabled(false);
         m_adaptScreenBtn->setEnabled(false);
-
-        //apple设备，不能旋转和删除
-        if (!QFileInfo(strPath).isWritable() || dApp->IsApplePhone())
+        m_ocrBtn->setEnabled(false);
+        //apple设备，不能旋转和删除 //新增保险箱的判断，保险箱无法删除,回收站也无法删除
+        if (!QFileInfo(strPath).isWritable() || dApp->IsApplePhone() ||  !utils::image::isCanRemove(strPath)) {
             m_trashBtn->setEnabled(false);
-        else
+        } else {
             m_trashBtn->setEnabled(true);
+        }
         return;
     }
     //判断是否加载完成，未完成将旋转按钮禁用
@@ -1520,15 +1503,15 @@ void TTBContent::setBtnAttribute(const QString strPath)
             m_rotateLBtn->setEnabled(true);
             m_rotateRBtn->setEnabled(true);
         } else {
-            if ((QFileInfo(strPath).suffix() == "svg")) {
-                m_rotateLBtn->setEnabled(true);
-                m_rotateRBtn->setEnabled(true);
-            } else {
-                m_rotateLBtn->setEnabled(false);
-                m_rotateRBtn->setEnabled(false);
-            }
+            //svg不再支持旋转
+            m_rotateLBtn->setEnabled(false);
+            m_rotateRBtn->setEnabled(false);
         }
     }
+    //新增保险箱的判断,回收站判断
+    if (!utils::image::isCanRemove(strPath)) {
+        m_trashBtn->setEnabled(false);
+    }
 
 }
 
@@ -1560,6 +1543,7 @@ void TTBContent::DisEnablettbButton()
     m_rotateRBtn->setEnabled(false);
     m_adaptImageBtn->setEnabled(false);
     m_adaptScreenBtn->setEnabled(false);
+    m_ocrBtn->setEnabled(false);
     m_NotImageViewFlag = true;
 }
 
@@ -1594,6 +1578,59 @@ void TTBContent::setAllEnabled(bool iRet)
     if (m_adaptScreenBtn) {
         m_adaptScreenBtn->setEnabled(iRet);
     }
+    if (m_ocrBtn) {
+        m_ocrBtn->setEnabled(iRet);
+    }
+}
+
+void TTBContent::slotMovePress(const QString &path)
+{
+    m_bMoving = false;
+    if (dApp->m_bMove) {
+        QString lastPath = m_strCurImagePath;
+        m_strCurImagePath = path;
+        m_lastIndex = m_nowIndex;
+
+        QList <ImageItem *>labelList = m_imgList->findChildren<ImageItem *>(path);
+        if (labelList.size() > 0) {
+            ImageItem *img = labelList.at(0);
+            if (nullptr != img) {
+                img->setIndexNow(m_nowIndex);
+                labelList.at(0)->setFixedSize(QSize(58, 58));
+                labelList.at(0)->resize(QSize(58, 58));
+                QPixmap pix = img->getPixmap();
+                m_nowIndex = img->getIndex();
+                emit showvaguepixmap(pix, labelList.at(0)->getPath());
+                emit sigsetcurrent(labelList.at(0)->getPath());
+            }
+        }
+        QList <ImageItem *>lastlabelList = m_imgList->findChildren<ImageItem *>(lastPath);
+        if (lastlabelList.size() > 0) {
+            ImageItem *img = lastlabelList.at(0);
+            if (nullptr != img) {
+                if (lastlabelList.at(0)->getIndex() != m_nowIndex) {
+                    lastlabelList.at(0)->setFixedSize(QSize(32, 40));
+                    lastlabelList.at(0)->resize(QSize(32, 40));
+                    lastlabelList.at(0)->setIndexNow(m_nowIndex);
+                }
+            }
+        }
+    }
+}
+
+void TTBContent::slotClickPress(int index, int indexNow, bool iRet)
+{
+    m_bMoving = true;
+    m_nowIndex = index;
+    emit imageMoveEnded(index, (index - indexNow), iRet);
+    m_lastIndex = m_nowIndex;
+}
+
+void TTBContent::slotChangeOcrBtn(bool iRet)
+{
+    if (m_ocrBtn) {
+        m_ocrBtn->setEnabled(iRet);
+    }
 }
 
 void TTBContent::onChangeHideFlags(bool bFlags)
@@ -1601,14 +1638,18 @@ void TTBContent::onChangeHideFlags(bool bFlags)
     m_bIsHide = bFlags;
     //heyi test 判断是否是第一次打开然后隐藏上一张和下一张按钮
     if (bFlags || m_imgInfos.size() <= 1) {
-        m_preButton->hide();
-        m_preButton_spc->hide();
-        m_nextButton->hide();
-        m_nextButton_spc->hide();
-        m_preButton->setEnabled(false);
-        m_preButton_spc->setEnabled(false);
-        m_nextButton->setEnabled(false);
-        m_nextButton_spc->setEnabled(false);
+        //平板下这里存在问题，因为平板默认最大化启动，且m_imgInfos的值存在问题，bug71844
+        if (!dApp->isPanelDev()) {
+            m_preButton->hide();
+            m_preButton_spc->hide();
+            m_nextButton->hide();
+            m_nextButton_spc->hide();
+            m_preButton->setEnabled(false);
+            m_preButton_spc->setEnabled(false);
+            m_nextButton->setEnabled(false);
+            m_nextButton_spc->setEnabled(false);
+            qDebug() << "1622 onchangehideflags";
+        }
     } else {
         m_preButton->show();
         m_nextButton->show();
@@ -1630,13 +1671,9 @@ void TTBContent::onChangeHideFlags(bool bFlags)
             m_rotateLBtn->setEnabled(true);
             m_rotateRBtn->setEnabled(true);
         } else {
-            if (QFileInfo(m_imagePath).suffix() == "svg") {
-                m_rotateLBtn->setEnabled(true);
-                m_rotateRBtn->setEnabled(true);
-            } else {
-                m_rotateLBtn->setEnabled(false);
-                m_rotateRBtn->setEnabled(false);
-            }
+            //svg不再支持旋转
+            m_rotateLBtn->setEnabled(false);
+            m_rotateRBtn->setEnabled(false);
         }
     }
 }
@@ -1661,51 +1698,9 @@ void TTBContent::loadBack(DBImgInfoList infos)
         /*LMH0727*/
         //imageItem->setObjectName(QString("%1").arg(m_totalImageItem++));
         m_imglayout->addWidget(imageItem);
-        connect(imageItem, &ImageItem::imageMoveclicked, this,
-        [ = ](QString path) {
-            m_bMoving = false;
-            if (dApp->m_bMove) {
-                m_lastIndex = m_nowIndex;
-                QList <ImageItem *>labelList = m_imgList->findChildren<ImageItem *>(path);
-                if (labelList.size() > 0) {
-                    ImageItem *img = labelList.at(0);
-                    if (nullptr != img) {
-                        img->setIndexNow(m_nowIndex);
-                        labelList.at(0)->setFixedSize(QSize(58, 58));
-                        labelList.at(0)->resize(QSize(58, 58));
-                        QPixmap pix = img->getPixmap();
-                        m_nowIndex = img->getIndex();
-                        emit showvaguepixmap(pix, labelList.at(0)->getPath());
-                        emit sigsetcurrent(labelList.at(0)->getPath());
-                    }
-                }
-                if (m_lastIndex > -1) {
-                    QList <ImageItem *>lastlabelList = m_imgList->findChildren<ImageItem *>(/*QString("%1").arg(m_lastIndex)*/);
-                    if (lastlabelList.isEmpty()) {
-                    } else {
-                        for (int i = 0; i < lastlabelList.size(); i++) {
-                            if (lastlabelList.at(i)->getIndex() != m_nowIndex) {
-                                lastlabelList.at(i)->setFixedSize(QSize(32, 40));
-                                lastlabelList.at(i)->resize(QSize(32, 40));
-                                lastlabelList.at(i)->setIndexNow(m_nowIndex);
-                            }
-                        }
-                    }
+        connect(imageItem, &ImageItem::imageMoveclicked, this, &TTBContent::slotMovePress);
 
-                }
-
-            }
-        });
-        connect(imageItem, &ImageItem::imageItemclicked, this,
-        [ = ](int index, int indexNow, bool iRet) {
-            m_bMoving = true;
-            m_nowIndex = index;
-//                emit imageClicked(index, (index - indexNow));
-            emit imageMoveEnded(index, (index - indexNow), iRet);
-            m_lastIndex = m_nowIndex;
-//            onResize();
-//            m_imgList->adjustSize();
-        });
+        connect(imageItem, &ImageItem::imageItemclicked, this, &TTBContent::slotClickPress);
 
         m_imgInfos.push_back(info);
         m_imgList->adjustSize();
@@ -1763,51 +1758,9 @@ void TTBContent::loadFront(DBImgInfoList infos)
         /*LMH0727*/
         //imageItem->setObjectName(QString("%1").arg(m_totalImageItem++));
         m_imglayout->insertWidget(0, imageItem);
-        connect(imageItem, &ImageItem::imageMoveclicked, this,
-        [ = ](QString path) {
-            m_bMoving = false;
-            if (dApp->m_bMove) {
-                m_lastIndex = m_nowIndex;
-                QList <ImageItem *>labelList = m_imgList->findChildren<ImageItem *>(path);
-                if (labelList.size() > 0) {
-                    ImageItem *img = labelList.at(0);
-                    if (nullptr != img) {
-                        img->setIndexNow(m_nowIndex);
-                        labelList.at(0)->setFixedSize(QSize(58, 58));
-                        labelList.at(0)->resize(QSize(58, 58));
-                        QPixmap pix = img->getPixmap();
-                        m_nowIndex = img->getIndex();
-                        emit showvaguepixmap(pix, labelList.at(0)->getPath());
-                        emit sigsetcurrent(labelList.at(0)->getPath());
-                    }
-                }
-                if (m_lastIndex > -1) {
-                    QList <ImageItem *>lastlabelList = m_imgList->findChildren<ImageItem *>(/*QString("%1").arg(m_lastIndex)*/);
-                    if (lastlabelList.isEmpty()) {
-                    } else {
-                        for (int i = 0; i < lastlabelList.size(); i++) {
-                            if (lastlabelList.at(i)->getIndex() != m_nowIndex) {
-                                lastlabelList.at(i)->setFixedSize(QSize(32, 40));
-                                lastlabelList.at(i)->resize(QSize(32, 40));
-                                lastlabelList.at(i)->setIndexNow(m_nowIndex);
-                            }
-                        }
-                    }
+        connect(imageItem, &ImageItem::imageMoveclicked, this, &TTBContent::slotMovePress);
 
-                }
-
-            }
-        });
-        connect(imageItem, &ImageItem::imageItemclicked, this,
-        [ = ](int index, int indexNow, bool iRet) {
-            m_bMoving = true;
-            m_nowIndex = index;
-//                emit imageClicked(index, (index - indexNow));
-            emit imageMoveEnded(index, (index - indexNow), iRet);
-            m_lastIndex = m_nowIndex;
-//            onResize();
-//            m_imgList->adjustSize();
-        });
+        connect(imageItem, &ImageItem::imageItemclicked, this, &TTBContent::slotClickPress);
 
         m_imgInfos.push_front(info);
         m_imgList->adjustSize();
@@ -1973,6 +1926,7 @@ void TTBContent::setImage(const QString path, DBImgInfoList infos)
         m_rotateLBtn->setEnabled(false);
         m_rotateRBtn->setEnabled(false);
         m_trashBtn->setEnabled(false);
+        m_ocrBtn->setEnabled(false);
 
         m_imgList->setEnabled(true);
 
@@ -1985,6 +1939,8 @@ void TTBContent::setImage(const QString path, DBImgInfoList infos)
         //        btFit->setEnabled(true);
         m_adaptImageBtn->setEnabled(true);
         m_adaptScreenBtn->setEnabled(true);
+        //解决动态图没有屏蔽ocr按钮的问题
+//        m_ocrBtn->setEnabled(true);
 #endif
 
         if (m_imgInfos.size() > 3) {
@@ -2105,6 +2061,7 @@ void TTBContent::setImage(const QString path, DBImgInfoList infos)
 #else
             //            btPre->hide();
             m_preButton->hide();
+            qDebug() << "2116 setImage";
 #endif
             m_preButton_spc->hide();
 #if TTB
