@@ -124,8 +124,9 @@ QVariantList cacheImage(const QString &path)
 {
     QImage tImg;
     QString errMsg;
+    QSize realSize;
 #if USE_UNIONIMAGE
-    UnionImage_NameSpace::loadStaticImageFromFile(path, tImg, errMsg);
+    UnionImage_NameSpace::loadStaticImageFromFile(path, tImg, realSize, errMsg);
 #else
     QString format = DetectImageFormat(path);
     QImageReader readerF(path, format.toLatin1());
@@ -254,9 +255,10 @@ QVariantList ImageView::cachePixmap(const QString path)
 
     QImage tImg;
     QString errMsg;
+    QSize realSize;
     if (!imageSupportRead(path)) {
         tImg = QImage();
-    } else if (!UnionImage_NameSpace::loadStaticImageFromFile(path, tImg, errMsg)) {
+    } else if (!UnionImage_NameSpace::loadStaticImageFromFile(path, tImg, realSize, errMsg)) {
         qDebug() << errMsg;
     }
     QPixmap p = QPixmap::fromImage(tImg);
@@ -264,7 +266,10 @@ QVariantList ImageView::cachePixmap(const QString path)
         dApp->m_rectmap.insert(path, p.rect());
         emit dApp->sigFinishLoad(path);
     }
-    dApp->m_imagemap.insert(path, p.scaledToHeight(IMAGE_HEIGHT_DEFAULT,  Qt::SmoothTransformation));
+    //如果图片为空，不会更新
+    if (!p.isNull()) {
+        dApp->m_imagemap.insert(path, p.scaledToHeight(IMAGE_HEIGHT_DEFAULT,  Qt::SmoothTransformation));
+    }
     emit dApp->signalM->sigUpdateThunbnail(path);//为了解决打开两个看图，一个看图旋转另一个看图没有更新缩略图的问题。
 //    if (QFileInfo(path).exists() && p.isNull()) {
 //        //判定为损坏图片
@@ -554,18 +559,14 @@ void ImageView::autoFit()
 
 void ImageView::titleBarControl()
 {
-    qDebug() << "imageHeight:"
-             << image().size().height() * imageRelativeScale() * devicePixelRatioF()
-             << image().size().height() * imageRelativeScale() << "&&&&&&"
-             << "currentHeight" << height() << "currentRatio" << devicePixelRatioF();
-
     qreal realHeight = 0.0;
-
+    //简化image()的使用
+    QImage img = image();
     if (m_movieItem /*|| m_imgSvgItem*/) {
-        realHeight = image().size().height() * imageRelativeScale() * devicePixelRatioF();
+        realHeight = img.size().height() * imageRelativeScale() * devicePixelRatioF();
 
     } else {
-        realHeight = image().size().height() * imageRelativeScale();
+        realHeight = img.size().height() * imageRelativeScale();
     }
 
     if (realHeight > height() - 100) {
@@ -599,6 +600,10 @@ const QImage ImageView::image(bool brefresh)
 void ImageView::fitWindow()
 {
     qreal wrs = windowRelativeScale();
+    //解决bug72018，平板模式下最大为200%缩放
+    if (dApp->isPanelDev() && wrs > 2) {
+        wrs = 2;
+    }
     m_scal = wrs;
     resetTransform();
     scale(wrs, wrs);
@@ -612,14 +617,21 @@ void ImageView::fitWindow()
     m_isFitWindow = true;
     scaled(imageRelativeScale() * devicePixelRatioF() * 100);
     emit transformChanged();
-    //20210115lmh因为每次退出全屏需要先reisizeEvent，所以image的尺寸没有刷新，这里需要再次判断
-    titleBarControl();
+    //20210115因为每次退出全屏需要先reisizeEvent，所以image的尺寸没有刷新，这里需要再次判断
+    //需要延时去处理标题的透明与否操作，否则无效，事件存在异步的问题
+    QTimer::singleShot(100, [ = ] {
+        titleBarControl();
+    });
 }
 
 void ImageView::fitWindow_btnclicked()
 {
     qreal wrs = windowRelativeScale_origin();
     resetTransform();
+    //解决bug72018，平板模式下最大为200%缩放
+    if (dApp->isPanelDev() && wrs > 2) {
+        wrs = 2;
+    }
     m_scal = wrs;
     scale(wrs, wrs);
     if (wrs - 1 > -0.01 && wrs - 1 < 0.01) {
@@ -647,6 +659,12 @@ void ImageView::fitImage()
     m_isFitWindow = false;
     scaled(imageRelativeScale() * devicePixelRatioF() * 100);
     emit transformChanged();
+
+    //20210115lmh因为每次退出全屏需要先reisizeEvent，所以image的尺寸没有刷新，这里需要再次判断,解决68086
+    //需要延时去处理标题的透明与否操作，否则无效，事件存在异步的问题
+    QTimer::singleShot(100, [ = ] {
+        titleBarControl();
+    });
 }
 
 bool ImageView::rotateClockWise()
@@ -685,37 +703,23 @@ qreal ImageView::imageRelativeScale() const
 
 qreal ImageView::windowRelativeScale() const
 {
+    //替换为相册的撑满方案
     QRectF bf = sceneRect();
-    if (this->window()->isFullScreen()) {
-        if (1.0 * (width()) / (height() + 15) > 1.0 * bf.width() / bf.height()) {
-            return 1.0 * (height() + 15) / bf.height();
-        } else {
-            return 1.0 * (width()) / bf.width();
-        }
+    if (1.0 * width() / height() > 1.0 * bf.width() / bf.height()) {
+        return 1.0 * height() / bf.height();
     } else {
-        if (1.0 * (width() - 20) / (height() - 180) > 1.0 * bf.width() / bf.height()) {
-            return 1.0 * (height() - 180) / bf.height();
-        } else {
-            return 1.0 * (width() - 20) / bf.width();
-        }
+        return 1.0 * width() / bf.width();
     }
 }
 
 qreal ImageView::windowRelativeScale_origin() const
 {
+    //替换为相册的撑满方案
     QRectF bf = sceneRect();
-    if (this->window()->isFullScreen()) {
-        if (1.0 * (width()) / (height()) > 1.0 * bf.width() / bf.height()) {
-            return 1.0 * (height()) / bf.height();
-        } else {
-            return 1.0 * (width()) / bf.width();
-        }
+    if (1.0 * width() / height() > 1.0 * bf.width() / bf.height()) {
+        return 1.0 * height() / bf.height();
     } else {
-        if (1.0 * (width()) / (height()) > 1.0 * bf.width() / bf.height()) {
-            return 1.0 * (height()) / bf.height();
-        } else {
-            return 1.0 * (width()) / bf.width();
-        }
+        return 1.0 * width() / bf.width();
     }
 }
 
@@ -910,6 +914,7 @@ bool ImageView::loadPictureByType(ImageView::PICTURE_TYPE type, const QString st
     m_bRoate = UnionImage_NameSpace::isImageSupportRotate(strPath) && QFileInfo(strPath).isWritable();
     switch (type) {
     case PICTURE_TYPE::SVG: {
+        emit currentIsDynamic(false);
         //svg采用svgRender显示
         m_movieItem = nullptr;
         m_pixmapItem = nullptr;
@@ -920,6 +925,8 @@ bool ImageView::loadPictureByType(ImageView::PICTURE_TYPE type, const QString st
         svgRenderer->load(strPath);
         m_imgSvgItem = new ImageSvgItem();
         m_imgSvgItem->setSharedRenderer(svgRenderer);
+        //不会出现锯齿
+        m_imgSvgItem->setCacheMode(QGraphicsItem::NoCache);
         setSceneRect(m_imgSvgItem->boundingRect());
         s->addItem(m_imgSvgItem);
 
@@ -945,6 +952,7 @@ bool ImageView::loadPictureByType(ImageView::PICTURE_TYPE type, const QString st
         break;
     }
     case PICTURE_TYPE::NORMAL: {
+        emit currentIsDynamic(false);
         m_movieItem = nullptr;
         m_imgSvgItem = nullptr;
         qDebug() << "cache start!";
@@ -1007,6 +1015,7 @@ bool ImageView::loadPictureByType(ImageView::PICTURE_TYPE type, const QString st
     }
 
     case PICTURE_TYPE::KINETOGRAM: {
+        emit currentIsDynamic(true);
         if (m_morePicFloatWidget) {
             m_morePicFloatWidget->setVisible(false);
         }
@@ -1197,6 +1206,7 @@ void ImageView::mouseReleaseEvent(QMouseEvent *e)
         int xpos = e->pos().x() - m_startpointx;
         if ((QDateTime::currentMSecsSinceEpoch() - m_clickTime) < 200 && abs(xpos) < 50) {
             m_clickTime = QDateTime::currentMSecsSinceEpoch();
+            emit doubleClicked();
         }
     }
     QGraphicsView::mouseReleaseEvent(e);
@@ -1204,7 +1214,7 @@ void ImageView::mouseReleaseEvent(QMouseEvent *e)
     viewport()->setCursor(Qt::ArrowCursor);
     if (e->source() == Qt::MouseEventSynthesizedByQt && m_maxTouchPoints == 1) {
         const QRect &r = visibleImageRect();
-        //double left=r.width()+r.x();
+        double left = r.width() + r.x();
         const QRectF &sr = sceneRect();
         //fix 42660 2020/08/14 单指时间在QEvent处理，双指手势通过手势处理。为了解决图片放大后单指滑动手势冲突的问题
         if ((r.width() >= sr.width() && r.height() >= sr.height())) {
@@ -1218,14 +1228,17 @@ void ImageView::mouseReleaseEvent(QMouseEvent *e)
             }
         } else {
             if (dApp->isPanelDev()) {
-                QScreen *screen = QGuiApplication::primaryScreen();
-                QSize screen_size = screen->size();
-                int xpos = e->pos().x() - m_startpointx;
-                if (abs(xpos) > screen_size.width() / 2 && m_startpointx != 0) {
-                    if (xpos > 0) {
-                        emit previousRequested();
-                    } else {
-                        emit nextRequested();
+                //比较大的图片必须拖动到触碰边界才能滑动
+                if ((left - sr.width() >= -1 && left - sr.width() <= 1) || (r.x() <= 1) || (r.width() >= sr.width())) {
+                    QScreen *screen = QGuiApplication::primaryScreen();
+                    QSize screen_size = screen->size();
+                    int xpos = e->pos().x() - m_startpointx;
+                    if (abs(xpos) > screen_size.width() / 2 && m_startpointx != 0) {
+                        if (xpos > 0) {
+                            emit previousRequested();
+                        } else {
+                            emit nextRequested();
+                        }
                     }
                 }
             }
@@ -1280,7 +1293,6 @@ void ImageView::resizeEvent(QResizeEvent *event)
     }
     // when resize window, make titlebar changed.
     if (!image().isNull()) {
-
         titleBarControl();
     }
 
@@ -1370,11 +1382,6 @@ bool ImageView::event(QEvent *event)
 void ImageView::onCacheFinish(QVariantList vl)
 {
     qDebug() << "cache end!";
-    QScreen *screen = QGuiApplication::primaryScreen();
-    QRect mm = screen->availableGeometry() ;
-    int screen_width = mm.width();
-    int screen_height = mm.height();
-    qDebug() << screen_width << screen_height;
 
     bool bpix = false;
     //QVariantList vl = m_watcher.result();
@@ -1776,9 +1783,14 @@ void ImageView::slotsUp()
             }
         }
         m_pixmapItem = nullptr;
+        m_pixmapItem = nullptr;
+        m_imgSvgItem = nullptr;
         scene()->clear();
 
-        m_pixmapItem = new GraphicsPixmapItem(QPixmap::fromImage(m_imageReader->read()));
+        resetTransform();
+        QPixmap pixmap = QPixmap::fromImage(m_imageReader->read());
+        pixmap.setDevicePixelRatio(devicePixelRatioF());
+        m_pixmapItem = new GraphicsPixmapItem(pixmap);
         scene()->addItem(m_pixmapItem);
         QRectF rect = m_pixmapItem->boundingRect();
         setSceneRect(rect);
@@ -1817,10 +1829,15 @@ void ImageView::slotsDown()
             m_imageReader->jumpToNextImage();
             m_currentMoreImageNum++;
         }
+        //修复bug69273,缩放存在问题
         m_pixmapItem = nullptr;
+        m_pixmapItem = nullptr;
+        m_imgSvgItem = nullptr;
         scene()->clear();
-
-        m_pixmapItem = new GraphicsPixmapItem(QPixmap::fromImage(m_imageReader->read()));
+        resetTransform();
+        QPixmap pixmap = QPixmap::fromImage(m_imageReader->read());
+        pixmap.setDevicePixelRatio(devicePixelRatioF());
+        m_pixmapItem = new GraphicsPixmapItem(pixmap);
         scene()->addItem(m_pixmapItem);
         QRectF rect = m_pixmapItem->boundingRect();
         setSceneRect(rect);
@@ -1871,7 +1888,9 @@ void ImageView::setCurrentImage(int index)
         m_currentMoreImageNum = 0;
         m_pixmapItem = nullptr;
         scene()->clear();
-        m_pixmapItem = new GraphicsPixmapItem(QPixmap::fromImage(m_imageReader->read()));
+        QPixmap pixmap = QPixmap::fromImage(m_imageReader->read());
+        pixmap.setDevicePixelRatio(devicePixelRatioF());
+        m_pixmapItem = new GraphicsPixmapItem(pixmap);
         scene()->addItem(m_pixmapItem);
         QRectF rect = m_pixmapItem->boundingRect();
         setSceneRect(rect);
@@ -1891,3 +1910,11 @@ void ImageView::setCurrentImage(int index)
 
     emit dApp->signalM->UpdateNavImg();
 }
+
+void ImageView::slotsOcrCurrentPicture()
+{
+    //如果不是移动过程中，才可以调用OCR
+    if (!dApp->m_bMove) {
+        dApp->sendOcrPicture(image(), m_path);
+    }
+}
