@@ -141,12 +141,7 @@ QString ViewPanel::moduleName()
 
 void ViewPanel::initConnect()
 {
-    //heyi  test
-    connect(dApp->signalM, &SignalManager::sigisThumbnailsContainPath, this, &ViewPanel::slotThumbnailContainPath);
-    connect(dApp->signalM, &SignalManager::sigGetLastThumbnailPath, this, &ViewPanel::slotGetLastThumbnailPath);
-    connect(dApp->signalM, &SignalManager::sigGetFirstThumbnailpath, this, &ViewPanel::slotGetFirstThumbnailPath);
-    connect(dApp->signalM, &SignalManager::sigLoadfrontSlideshow, this, &ViewPanel::SlotLoadFrontThumbnailsAndClearTail);
-    connect(dApp->signalM, &SignalManager::sigLoadTailThumbnail, this, &ViewPanel::slotLoadTailThumbnailsAndClearFront);
+
     connect(this, &ViewPanel::sendLoadOver, this, &ViewPanel::sendSignal, Qt::QueuedConnection);
     connect(dApp, &Application::endThread, this, [ = ]() {
         m_bThreadExit = true;
@@ -192,8 +187,8 @@ void ViewPanel::initConnect()
     qRegisterMetaType<SignalManager::ViewInfo>("SignalManager::ViewInfo");
     connect(dApp->signalM, &SignalManager::viewImageNoNeedReload,
     this, [ = ](QString & filename) {
-//        emit imageChanged(filename);
-//        openImage(filename);
+        //        emit imageChanged(filename);
+        //        openImage(filename);
         int fileindex = imageIndex(filename);
         if (fileindex >= 0) {
             showImage(fileindex, 0);
@@ -218,45 +213,10 @@ void ViewPanel::initConnect()
         emit dApp->signalM->updateTopToolbarMiddleContent(toolbarTopMiddleContent());
 
         onViewImage(vinfo);
-        if (nullptr == vinfo.lastPanel) {
-            return;
-        } else if (vinfo.lastPanel->moduleName() == "AlbumPanel" ||
-                   vinfo.lastPanel->moduleName() == "ViewPanel") {
-            m_currentImageLastDir = vinfo.album;
-            emit viewImageFrom(vinfo.album);
-        } else if (vinfo.lastPanel->moduleName() == "TimelinePanel") {
-            m_currentImageLastDir = tr("Timeline");
-            emit viewImageFrom(tr("Timeline"));
-        }
+
         // TODO: there will be some others panel
     });
 
-#ifndef LITE_DIV
-    connect(dApp->signalM, &SignalManager::removedFromAlbum, this,
-    [ = ](const QString & album, const QStringList & paths) {
-        if (!isVisible() || album != m_vinfo.album || m_vinfo.album.isEmpty()) {
-            return;
-        }
-        foreach (QString path, paths) {
-            if (imageIndex(path) == imageIndex(m_current->filePath)) {
-                removeCurrentImage();
-            }
-        }
-    });
-#endif
-    connect(dApp->signalM, &SignalManager::imagesRemoved, this, [ = ](const DBImgInfoList & infos) {
-        if (m_infos.length() > 0) {
-            removeCurrentImage();
-            ttbc->setIsConnectDel(true);
-            m_bAllowDel = true;
-            ttbc->disableDelAct(true);
-        }
-
-        infos.size();
-        //add by heyi 判断当前图片是否被旋转
-        m_viewB->rotatePixCurrent();
-        updateMenuContent();
-    });
     connect(m_viewB, &ImageView::mouseHoverMoved, this, &ViewPanel::mouseMoved);
     connect(m_viewB, &ImageView::sigUpdateImageView, this, &ViewPanel::slotUpdateImageView);
     connect(this, &ViewPanel::sigStopshowThread, m_viewB, &ImageView::SlotStopShowThread);
@@ -265,6 +225,7 @@ void ViewPanel::initConnect()
     connect(dApp->signalM, &SignalManager::sigOpenFileDialog, this, [ = ] {
         emit m_emptyWidget->openImageInDialog();
     });
+    connect(m_viewB, &ImageView::currentIsDynamic, this, &ViewPanel::slotOpenOcrBtn);
 #ifdef LITE_DIV
 
     //LMH
@@ -282,6 +243,8 @@ void ViewPanel::initConnectOpenImage()
     connect(m_emptyWidget, &ThumbnailWidget::nextRequested, this, &ViewPanel::showNext);
     connect(m_lockWidget, &LockWidget::previousRequested, this, &ViewPanel::showPrevious);
     connect(m_lockWidget, &LockWidget::nextRequested, this, &ViewPanel::showNext);
+    connect(m_lockWidget, &LockWidget::showfullScreen, this, &ViewPanel::toggleFullScreen);
+
     connect(m_emptyWidget, &ThumbnailWidget::openImageInDialog, this, [this] {
         QString filter = tr("All images");
 
@@ -299,11 +262,13 @@ void ViewPanel::initConnectOpenImage()
         }
         pictureFolder =
         dApp->setter->value(cfgGroupName, cfgLastOpenPath, pictureFolder).toString();
-
+#ifndef USE_TEST
         const QStringList &image_list =
         QFDToDFileDialog::getOpenFileNames(this, tr("Open Image"), pictureFolder, filter, nullptr,
                                            QFDToDFileDialog::HideNameFilterDetails);
-
+#else
+        const QStringList image_list = QStringList(QApplication::applicationDirPath() + "/test/jpg113.jpg");
+#endif
         if (image_list.isEmpty())
             return;
 
@@ -423,6 +388,9 @@ bool ViewPanel::PopRenameDialog(QString &filepath, QString &filename)
         bool bOk = file.rename(filepath);
         if (bOk)
             emit dApp->signalM->updateFileName(renamedlg->GetFileName());
+#ifdef USE_TEST
+        return true;
+#endif
         return bOk;
     } else {
         if (!m_menu || !m_menu->isVisible()) {
@@ -507,96 +475,20 @@ void ViewPanel::startFileWatcher()
 
 }
 
-//void ViewPanel::disconnectTTbc()
-//{
-//    if (ttbc) {
-//        ttbc->disconnect();
-//    }
-//}
-
-//void ViewPanel::reConnectTTbc()
-//{
-//    connect(this, &ViewPanel::sigDisenablebutton, ttbc, &TTBContent::DisEnablettbButton, Qt::UniqueConnection);
-//    connect(this, &ViewPanel::changeHideFlag, ttbc, &TTBContent::onChangeHideFlags, Qt::UniqueConnection);
-//    connect(this, &ViewPanel::hidePreNextBtn, ttbc, &TTBContent::onHidePreNextBtn, Qt::UniqueConnection);
-//    connect(this, &ViewPanel::sendAllImageInfos, ttbc, &TTBContent::receveAllIamgeInfos, Qt::UniqueConnection);
-//    connect(this, &ViewPanel::disableDel, ttbc, &TTBContent::disableDelAct, Qt::UniqueConnection);
-
-//    connect(ttbc, &TTBContent::clicked, this, &ViewPanel::backToLastPanel, Qt::UniqueConnection);
-//    connect(this, &ViewPanel::viewImageFrom, ttbc,
-//    [ = ](const QString & dir) {
-//        ttbc->setCurrentDir(dir);
-//    }, Qt::UniqueConnection);
-
-//    connect(this, &ViewPanel::imageChanged, ttbc, &TTBContent::setImage, Qt::UniqueConnection);
-//    connect(ttbc, &TTBContent::rotateClockwise, this, [ = ] { rotateImage(true); }, Qt::UniqueConnection);
-//    connect(ttbc, &TTBContent::rotateCounterClockwise, this, [ = ] { rotateImage(false); }, Qt::UniqueConnection);
-//    connect(ttbc, &TTBContent::removed, this, [ = ] {
-//        if (m_dtr->isActive()) {
-//            return ;
-//        }
-//        m_dtr->start();
-//        if (m_vinfo.inDatabase)
-//        {
-//            popupDelDialog(m_infos.at(m_current).filePath);
-//        } else
-//        {
-//            const QString path = m_infos.at(m_current).filePath;
-//            QFile file(path);
-//            if (!file.exists()) {
-//                return;
-//            }
-
-//            if (removeCurrentImage()) {
-//                DDesktopServices::trash(path);
-//                emit dApp->signalM->picDelete();
-//                ttbc->setIsConnectDel(true);
-//                m_bAllowDel = true;
-//                ttbc->disableDelAct(true);
-//            }
-//        }
-//    }, Qt::UniqueConnection);
-
-//    connect(ttbc, &TTBContent::resetTransform, this, [ = ](bool fitWindow) {
-//        if (fitWindow) {
-//            m_viewB->fitWindow_btnclicked();
-//        } else {
-//            m_viewB->fitImage();
-//        }
-//        m_viewB->titleBarControl();
-//    }, Qt::UniqueConnection);
-
-//    connect(m_viewB, &ImageView::disCheckAdaptImageBtn, ttbc, &TTBContent::disCheckAdaptImageBtn, Qt::UniqueConnection);
-//    connect(m_viewB, &ImageView::checkAdaptImageBtn, ttbc, &TTBContent::checkAdaptImageBtn, Qt::UniqueConnection);
-//    connect(m_viewB, &ImageView::sigRequestShowVaguePix, ttbc, &TTBContent::OnRequestShowVaguePix, Qt::UniqueConnection);
-//    connect(dApp->signalM, &SignalManager::insertedIntoAlbum, ttbc,
-//            &TTBContent::updateCollectButton, Qt::UniqueConnection);
-//    connect(dApp->signalM, &SignalManager::removedFromAlbum, ttbc,
-//            &TTBContent::updateCollectButton, Qt::UniqueConnection);
-//    connect(ttbc, &TTBContent::showPrevious, this, [ = ]() {
-//        this->showPrevious();
-//    }, Qt::UniqueConnection);
-//    connect(ttbc, &TTBContent::showNext, this, [ = ]() {
-//        this->showNext();
-//    }, Qt::UniqueConnection);
-//    connect(ttbc, &TTBContent::imageClicked, this,
-//    [ = ](int index, int addIndex) {
-//        this->showImage(index, addIndex);
-//    }, Qt::UniqueConnection);
-//    /*lmh0731*/
-//    connect(ttbc, &TTBContent::imageMoveEnded, this,
-//                    [ = ](int index, int addIndex,bool iRet) {
-//        this->m_bIsOpenPicture=iRet;
-//        this->showImage(index, addIndex);
-//    }, Qt::UniqueConnection);
-//}
-
 bool ViewPanel::GetPixmapStatus(QString filename)
 {
     QPixmap pic = dApp->m_imagemap.value(filename);
     return !pic.isNull();
 }
 
+void ViewPanel::slotOpenOcrBtn(bool iRet)
+{
+    m_isDynamicPic = iRet;
+    if (ttbc) {
+        ttbc->slotChangeOcrBtn(!m_isDynamicPic);
+    }
+}
+
 void ViewPanel::slotCurrentStackWidget(QString &path, bool bpix)
 {
     //bpix表示图片加载成功，不用切换到撕裂图widget
@@ -606,6 +498,8 @@ void ViewPanel::slotCurrentStackWidget(QString &path, bool bpix)
         //存在线程时序的问题，应该这里如果图片为null，bpix应该设置为false，修复bug64355
         if (!pixmapthumb.isNull() || !pixmapgetthumb.isNull()) {
             bpix = true;
+            //解决bug，其他地方删除图片，显示为撕裂图的问题
+            pixmapthumb = pixmapgetthumb;
         } else {
             bpix = false;
         }
@@ -617,6 +511,7 @@ void ViewPanel::slotCurrentStackWidget(QString &path, bool bpix)
         else
             m_emptyWidget->setThumbnailImage(pixmapthumb);
         m_stack->setCurrentIndex(1);
+        slotOpenOcrBtn(true);
     } else if (!QFileInfo(path).isReadable() || !bpix) {
         emit sigDisenablebutton();
         //lmh2020/11/12 bug54164
@@ -624,6 +519,7 @@ void ViewPanel::slotCurrentStackWidget(QString &path, bool bpix)
             emit m_viewB->disCheckAdaptImageBtn();
         }
         m_stack->setCurrentIndex(2);
+        slotOpenOcrBtn(true);
     } else {
         m_stack->setCurrentIndex(0);
         // open success.
@@ -774,97 +670,6 @@ void ViewPanel::eatImageDirIteratorThread()
     emit sendLoadOver(m_infos, m_current);
 }
 
-
-
-void ViewPanel::SlotLoadFrontThumbnailsAndClearTail()
-{
-    if (!m_CollFileFinish)
-        return;
-    if (m_infosAll.size() == m_infos.size()) {
-        emit dApp->signalM->sigNoneedLoadfrontslideshow();
-        return;
-    }
-    m_infosHead.clear();
-    m_infos.clear();
-    m_infosTail = m_infosAll;
-    m_infoslideshow.clear();
-    for (int i = 0; i < Load_Image_Count; i++) {
-        if (m_infosTail.isEmpty()) break;
-        DBImgInfo info = m_infosTail.takeFirst();
-        m_infos.append(info);
-        QFileInfo file(info.filePath);
-        QString str = file.suffix();
-//        if (utils::image::supportedImageFormats().contains("*." + str, Qt::CaseInsensitive))
-//            m_infoslideshow.append(info);
-    }
-    QStringList pathlist;
-    emit dApp->signalM->sigLoadHeadThunbnail(m_infos);
-    //emit sigsendslideshowlist(false, m_infoslideshow);
-    for (int loop = 0; loop < m_infos.size(); loop++) {
-        pathlist.append(m_infos.at(loop).filePath);
-    }
-
-    if (pathlist.size() > 0) {
-        ttbc->setIsConnectDel(false);
-        m_bAllowDel = false;
-        ttbc->disableDelAct(false);
-        emit sendDynamicLoadPaths(pathlist);
-    }
-}
-
-void ViewPanel::slotGetLastThumbnailPath(QString &path)
-{
-    if (m_infos.size() > 1)
-        path = m_infos[m_infos.size() - 1].filePath;
-}
-
-void ViewPanel::slotThumbnailContainPath(QString path, bool &b)
-{
-    b = imageIndex(path) == -1 ? false : true;
-}
-
-void ViewPanel::slotLoadTailThumbnailsAndClearFront()
-{
-    if (!m_CollFileFinish)
-        return;
-    if (m_infosAll.size() == m_infos.size()) {
-        emit dApp->signalM->sigNoneedLoadfrontslideshow();
-        return;
-    }
-    m_infosHead = m_infosAll;
-    m_infos.clear();
-    m_infosTail.clear();
-    m_infoslideshow.clear();
-    for (int i = 0; i < Load_Image_Count; i++) {
-        if (m_infosHead.isEmpty()) break;
-        DBImgInfo info = m_infosHead.takeLast();
-        m_infos.insert(0, info);
-        QFileInfo file(info.filePath);
-        QString str = file.suffix();
-//        if (utils::image::supportedImageFormats().contains("*." + str, Qt::CaseInsensitive))
-//            m_infoslideshow.append(info);
-    }
-    QStringList pathlist;
-    emit dApp->signalM->sigLoadHeadThunbnail(m_infos);
-    //emit sigsendslideshowlist(false, m_infoslideshow);
-    for (int loop = 0; loop < m_infos.size(); loop++) {
-        pathlist.append(m_infos.at(loop).filePath);
-    }
-
-    if (pathlist.size() > 0) {
-        ttbc->setIsConnectDel(false);
-        m_bAllowDel = false;
-        ttbc->disableDelAct(false);
-        emit sendDynamicLoadPaths(pathlist);
-    }
-}
-
-void ViewPanel::slotGetFirstThumbnailPath(QString &path)
-{
-    if (m_infos.size() > 0)
-        path = m_infos[0].filePath;
-}
-
 void  ViewPanel::slotUpdateImageView(QString &path)
 {
     QPixmap pixmapthumb = dApp->m_imagemap.value(path);
@@ -915,12 +720,14 @@ void ViewPanel::showNormal()
     emit dApp->signalM->enterView(true);
 
     //加入动画效果，掩盖左上角展开的视觉效果，以透明度0-1显示。
-    QPropertyAnimation *pAn = new QPropertyAnimation(window(), "windowOpacity");
-    pAn->setDuration(50);
-    pAn->setEasingCurve(QEasingCurve::Linear);
-    pAn->setEndValue(1);
-    pAn->setStartValue(0);
-    pAn->start(QAbstractAnimation::DeleteWhenStopped);
+    if (!dApp->isPanelDev()) {
+        QPropertyAnimation *pAn = new QPropertyAnimation(window(), "windowOpacity");
+        pAn->setDuration(50);
+        pAn->setEasingCurve(QEasingCurve::Linear);
+        pAn->setEndValue(1);
+        pAn->setStartValue(0);
+        pAn->start(QAbstractAnimation::DeleteWhenStopped);
+    }
     if (m_isMaximized) {
         window()->showNormal();
         window()->showMaximized();
@@ -932,7 +739,7 @@ void ViewPanel::showNormal()
 //    window()->showNormal();
     emit dApp->signalM->showTopToolbar();
 }
-
+#include <QDesktopWidget>
 void ViewPanel::showFullScreen()
 {
     /*lmh0804改，增加设置窗口置顶*/
@@ -940,14 +747,15 @@ void ViewPanel::showFullScreen()
 //    window()->setWindowFlags(Qt::Widget);
     m_isMaximized = window()->isMaximized();
     // Full screen then hide bars because hide animation depends on height()
-    //加入动画效果，掩盖左上角展开的视觉效果，以透明度0-1显示。
-
-    QPropertyAnimation *pAn = new QPropertyAnimation(window(), "windowOpacity");
-    pAn->setDuration(50);
-    pAn->setEasingCurve(QEasingCurve::Linear);
-    pAn->setEndValue(1);
-    pAn->setStartValue(0);
-    pAn->start(QAbstractAnimation::DeleteWhenStopped);
+    //加入动画效果，掩盖左上角展开的视觉效果，以透明度0-1显示。,时间为50ms
+    if (!dApp->isPanelDev()) {
+        QPropertyAnimation *pAn = new QPropertyAnimation(window(), "windowOpacity");
+        pAn->setDuration(50);
+        pAn->setEasingCurve(QEasingCurve::Linear);
+        pAn->setEndValue(1);
+        pAn->setStartValue(0);
+        pAn->start(QAbstractAnimation::DeleteWhenStopped);
+    }
 
     window()->showFullScreen();
 
@@ -1026,10 +834,7 @@ QWidget *ViewPanel::toolbarTopLeftContent()
     }
 
     connect(ttlc, &TTLContent::clicked, this, &ViewPanel::backToLastPanel);
-    connect(this, &ViewPanel::viewImageFrom, ttlc,
-    [ = ](const QString & dir) {
-        ttlc->setCurrentDir(dir);
-    });
+
     //    connect(ttlc, &TTLContent::contentWidthChanged,
     //            this, &ViewPanel::updateTopLeftWidthChanged);
     //    connect(this, &ViewPanel::updateCollectButton,
@@ -1038,10 +843,7 @@ QWidget *ViewPanel::toolbarTopLeftContent()
     connect(ttlc, &TTLContent::rotateClockwise, this, [ = ] { rotateImage(true); });
     connect(ttlc, &TTLContent::rotateCounterClockwise, this, [ = ] { rotateImage(false); });
     connect(ttlc, &TTLContent::removed, this, [ = ] {
-        if (m_vinfo.inDatabase)
-        {
-            popupDelDialog(m_infos.at(m_current).filePath);
-        } else
+        if (!m_vinfo.inDatabase)
         {
             const QString path = m_infos.at(m_current).filePath;
             removeCurrentImage();
@@ -1083,7 +885,7 @@ QWidget *ViewPanel::bottomTopLeftContent()
     else
         flag = false;
     ttbc = new TTBContent(m_vinfo.inDatabase, m_infos, flag, this);
-
+    ttbc->slotChangeOcrBtn(!m_isDynamicPic);
     if (!ttbc) {
         return nullptr;
     }
@@ -1098,25 +900,13 @@ QWidget *ViewPanel::bottomTopLeftContent()
     connect(this, &ViewPanel::sendLoadAddInfos, ttbc, &TTBContent::recvLoadAddInfos);
 
     connect(dApp->signalM, &SignalManager::sendLoadSignal, this, &ViewPanel::recvLoadSignal, Qt::UniqueConnection);
-    //    ttlc->setCurrentDir(m_currentImageLastDir);
-//    if (!m_infos.isEmpty() && m_current < m_infos.size()) {
-//        ttbc->setImage(m_infos.at(m_current).filePath, m_infos);
-//    } else {
-//        ttbc->setImage("", m_infos);
-//    }
-
     connect(ttbc, &TTBContent::clicked, this, &ViewPanel::backToLastPanel);
-    connect(this, &ViewPanel::viewImageFrom, ttbc,
-    [ = ](const QString & dir) {
-        ttbc->setCurrentDir(dir);
-    });
-    //    connect(ttlc, &TTLContent::contentWidthChanged,
-    //            this, &ViewPanel::updateTopLeftWidthChanged);
-    //    connect(this, &ViewPanel::updateCollectButton,
-    //            ttlc, &TTLContent::updateCollectButton);
     connect(this, &ViewPanel::imageChanged, ttbc, &TTBContent::setImage);
     connect(ttbc, &TTBContent::rotateClockwise, this, [ = ] { rotateImage(true); });
     connect(ttbc, &TTBContent::rotateCounterClockwise, this, [ = ] { rotateImage(false); });
+
+    connect(ttbc, &TTBContent::ocrCurrentPicture, m_viewB, &ImageView::slotsOcrCurrentPicture);
+
     connect(ttbc, &TTBContent::removed, this, [ = ] {
 
         if (m_dtr->isActive())
@@ -1124,10 +914,7 @@ QWidget *ViewPanel::bottomTopLeftContent()
             return ;
         }
         m_dtr->start();
-        if (m_vinfo.inDatabase)
-        {
-            popupDelDialog(m_infos.at(m_current).filePath);
-        } else
+        if (!m_vinfo.inDatabase)
         {
             const QString path = m_infos.at(m_current).filePath;
             QFile file(path);
@@ -1136,7 +923,9 @@ QWidget *ViewPanel::bottomTopLeftContent()
             }
 
             //先删除文件，需要判断文件是否删除，如果删除了，再决定看图软件的显示
-            DDesktopServices::trash(path);
+            //不再采用默认删除,使用utils里面的删除
+            utils::base::trashFile(path);
+
             QFile fileRemove(path);
             //文件是否被删除的判断bool值
             bool iRetRemove = false;
@@ -1469,9 +1258,10 @@ void ViewPanel::onViewImage(const SignalManager::ViewInfo &vinfo)
         m_bOnlyOneiImg = false;
         dApp->setIsOnlyOnePic(false);
     }
-    if (vinfo.paths.count() < 2) {
-        dApp->setIsOnlyOnePic(true);
-    }
+    //存在info只有一个情况，这里暂时不做操作
+//    if (vinfo.paths.count() < 2) {
+//        dApp->setIsOnlyOnePic(true);
+//    }
 
     //apple手机，无旋转和删除权限
     if (m_bOnlyOneiImg && path.indexOf("gphoto2:host=Apple") != -1) {
@@ -1789,7 +1579,8 @@ bool ViewPanel::showImage(int index, int addindex)
 
 bool ViewPanel::removeCurrentImage()
 {
-    if (m_infos.isEmpty() || !m_bAllowDel) {
+    //删除m_bAllowDel的判断，这是一个异步处理，不符合当前场景，手速快会导致删除成功了，但是显示错误
+    if (m_infos.isEmpty()) {
         return false;
     }
 
