@@ -65,6 +65,11 @@ QString ss(const QString &text, const QString &defaultValue)
 
 void ViewPanel::initPopupMenu()
 {
+    QShortcut *ctrlm = new QShortcut(QKeySequence("Ctrl+M"), this);
+    ctrlm->setContext(Qt::WindowShortcut);
+    connect(ctrlm, &QShortcut::activated, this, [ = ] {
+        this->customContextMenuRequested(cursor().pos());
+    });
     if (!dApp->isPanelDev()) {
         m_menu = new DMenu;
         connect(this, &ViewPanel::customContextMenuRequested, this, [ = ] {
@@ -103,39 +108,6 @@ void ViewPanel::appendAction(int id, const QString &text, const QString &shortcu
     }
 }
 
-#ifndef LITE_DIV
-DMenu *ViewPanel::createAlbumMenu()
-{
-    if (m_infos.isEmpty() || m_current == m_infos.constEnd() || !m_vinfo.inDatabase) {
-        return nullptr;
-    }
-
-    DMenu *am = new DMenu(tr("Add to album"));
-    QStringList albums = DBManager::instance()->getAllAlbumNames();
-    albums.removeAll(FAVORITES_ALBUM_NAME);
-
-    QAction *ac = new QAction(am);
-    ac->setProperty("MenuID", IdAddToAlbum);
-    ac->setText(tr("Add to new album"));
-    ac->setData(QString("Add to new album"));
-    am->addAction(ac);
-    am->addSeparator();
-    for (QString album : albums) {
-        const QStringList paths = DBManager::instance()->getPathsByAlbum(album);
-        if (!paths.contains(m_current->filePath)) {
-            QAction *ac = new QAction(am);
-            ac->setProperty("MenuID", IdAddToAlbum);
-            ac->setText(
-                fontMetrics().elidedText(QString(album).replace("&", "&&"), Qt::ElideMiddle, 200));
-            ac->setData(album);
-            am->addAction(ac);
-        }
-    }
-
-    return am;
-}
-#endif
-
 void ViewPanel::onMenuItemClicked(QAction *action)
 {
     using namespace utils::base;
@@ -233,17 +205,7 @@ void ViewPanel::onMenuItemClicked(QAction *action)
         }
         break;
     }
-#ifndef LITE_DIV
-    case IdAddToAlbum: {
-        const QString album = action->data().toString();
-        if (album != "Add to new album") {
-            DBManager::instance()->insertIntoAlbum(album, QStringList(path));
-        } else {
-            dApp->signalM->createAlbum(QStringList(path));
-        }
-        break;
-    }
-#endif
+
     case IdCopy:
         copyImageToClipboard(QStringList(path));
         break;
@@ -253,9 +215,7 @@ void ViewPanel::onMenuItemClicked(QAction *action)
             return ;
         }
         m_dtr->start();
-        if (m_vinfo.inDatabase) {
-            popupDelDialog(path);
-        } else {
+        if (!m_vinfo.inDatabase) {
             QFile file(path);
             if (!file.exists())
                 break;
@@ -280,19 +240,7 @@ void ViewPanel::onMenuItemClicked(QAction *action)
             }
         }
         break;
-#ifndef LITE_DIV
-    case IdRemoveFromAlbum:
-        DBManager::instance()->removeFromAlbum(m_vinfo.album, QStringList(path));
-        break;
-    case IdAddToFavorites:
-        DBManager::instance()->insertIntoAlbum(FAVORITES_ALBUM_NAME, QStringList(path));
-        emit updateCollectButton();
-        break;
-    case IdRemoveFromFavorites:
-        DBManager::instance()->removeFromAlbum(FAVORITES_ALBUM_NAME, QStringList(path));
-        emit updateCollectButton();
-        break;
-#endif
+
     case IdShowNavigationWindow:
         m_nav->setAlwaysHidden(false);
         break;
@@ -332,6 +280,9 @@ void ViewPanel::onMenuItemClicked(QAction *action)
         emit dApp->signalM->sigDrawingBoard(pathlist);
         break;
     }
+    case IdOcr: {
+        m_viewB->slotsOcrCurrentPicture();
+    }
     default:
         break;
     }
@@ -354,53 +305,32 @@ void ViewPanel::updateMenuContent()
         } else {
             appendAction(IdFullScreen, tr("Fullscreen"), ss("Fullscreen", "F11"));
         }
-#ifndef LITE_DIV
-        appendAction(IdStartSlideShow, tr("Slide show"), ss("Slide show"));
-#endif
+
         appendAction(IdPrint, tr("Print"), ss("Print", "Ctrl+P"));
+        //ocr按钮
+        if (!m_isDynamicPic) {
+            appendAction(IdOcr, tr("Extract text"), ss("Extract text", "Alt+O"));
+        }
         //修复打开不支持显示的图片在缩略图中没有，current出现超出界限崩溃问题
         if (m_current >= m_infos.size()) m_current = 0;
         QFileInfo currfileinfo(m_infos.at(m_current).filePath);
-        if (currfileinfo.isReadable() &&
-                currfileinfo.isWritable())
-            appendAction(IdRename, tr("Rename"), ss("Rename", "F2"));
 
         //判断图片数量大于0才能执行幻灯片播放
         if (m_infos.size() > 0) {
             appendAction(IdStartSlideShow, tr("Slide show"), ss("Slide show", "F5"));
         }
-#ifndef LITE_DIV
-        if (m_vinfo.inDatabase) {
-            DMenu *am = createAlbumMenu();
-            if (am) {
-                m_menu->addMenu(am);
-            }
-        }
-#endif
+
         m_menu->addSeparator();
         /**************************************************************************/
         appendAction(IdCopy, tr("Copy"), ss("Copy", "Ctrl+C"));
-
-        //apple phone的delete没有权限
-        if ((currfileinfo.isReadable() && currfileinfo.isWritable()) && !dApp->IsApplePhone()) {
+        if (currfileinfo.isReadable() &&
+                currfileinfo.isWritable())
+            appendAction(IdRename, tr("Rename"), ss("Rename", "F2"));
+        //apple phone的delete没有权限,保险箱无法删除,垃圾箱也无法删除
+        if ((currfileinfo.isReadable() && currfileinfo.isWritable()) && !dApp->IsApplePhone() && utils::image::isCanRemove(m_currentImagePath)) {
             appendAction(IdMoveToTrash, tr("Delete"), ss("Throw to trash", "Delete"));
         }
 
-#ifndef LITE_DIV
-        if (!m_vinfo.album.isEmpty()) {
-            appendAction(IdRemoveFromAlbum, tr("Remove from album"), ss("Remove from album"));
-        }
-        m_menu->addSeparator();
-        /**************************************************************************/
-        if (m_vinfo.inDatabase) {
-            if (m_current != m_infos.constEnd() &&
-                    !DBManager::instance()->isImgExistInAlbum(FAVORITES_ALBUM_NAME, m_current->filePath)) {
-                appendAction(IdAddToFavorites, tr("Favorite"), ss("Favorite"));
-            } else {
-                appendAction(IdRemoveFromFavorites, tr("Unfavorite"), ss("UnfappendAction(IdRename, tr("Rename"), ss("Rename", "F2"));avorite"));
-            }
-        }
-#endif
         m_menu->addSeparator();
         /**************************************************************************/
         if (!m_viewB->isWholeImageVisible() && m_nav->isAlwaysHidden() && GetPixmapStatus(m_currentImagePath)) {
@@ -426,9 +356,6 @@ void ViewPanel::updateMenuContent()
         if (m_stack->currentIndex() == 0 && utils::image::imageSupportWallPaper(m_infos.at(m_current).filePath)) {
             appendAction(IdSetAsWallpaper, tr("Set as wallpaper"), ss("Set as wallpaper", "Ctrl+F9"));
         }
-#ifndef LITE_DIV
-        if (m_vinfo.inDatabase)
-#endif
         {
             appendAction(IdDisplayInFileManager, tr("Display in file manager"),
                          ss("Display in file manager", "Alt+D"));
@@ -540,13 +467,3 @@ void ViewPanel::initShortcut()
     });
 }
 
-void ViewPanel::popupDelDialog(const QString path)
-{
-#ifndef LITE_DIV
-    const QStringList paths(path);
-    FileDeleteDialog *fdd = new FileDeleteDialog(paths);
-    fdd->showInCenter(window());
-#else
-    Q_UNUSED(path)
-#endif
-}
