@@ -18,6 +18,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#include "application.h"
 #include "utils/baseutils.h"
 #include "utils/imageutils.h"
 #include "utils/imageutils_libexif.h"
@@ -56,10 +57,13 @@ const QImage scaleImage(const QString &path, const QSize &size)
 #ifdef USE_UNIONIMAGE
     QImage tImg(size, QImage::Format_ARGB32);
     QString errMsg;
-    if (!UnionImage_NameSpace::loadStaticImageFromFile(path, tImg, errMsg)) {
+    QSize realSize;
+    if (!UnionImage_NameSpace::loadStaticImageFromFile(path, tImg, realSize, errMsg)) {
         qDebug() << errMsg;
     }
-    tImg = tImg.scaled(size);
+    if (tImg.size() != size) { //调用加速接口失败，主动进行缩放
+        tImg = tImg.scaled(size);
+    }
     return tImg;
 #else
     QImageReader reader(path);
@@ -508,7 +512,8 @@ const QImage getRotatedImage(const QString &path)
     /*lmh0724使用USE_UNIONIMAGE*/
 #ifdef USE_UNIONIMAGE
     QString errMsg;
-    if (!UnionImage_NameSpace::loadStaticImageFromFile(path, tImg, errMsg)) {
+    QSize realSize;
+    if (!UnionImage_NameSpace::loadStaticImageFromFile(path, tImg, realSize, errMsg)) {
         qDebug() << errMsg;
     }
 #else
@@ -621,7 +626,10 @@ QMutex mutex;
 const QPixmap getThumbnail(const QString &path, bool cacheOnly)
 {
     QMutexLocker locker(&mutex);
-
+    //优先读取自身缓存的图片
+    if (dApp->m_imagemap.value(path).isNull()) {
+        return dApp->m_imagemap.value(path);
+    }
     const QString cacheP = thumbnailCachePath();
     const QUrl url = QUrl::fromLocalFile(path);
     const QString md5s = toMd5(url.toString(QUrl::FullyEncoded).toLocal8Bit());
@@ -845,8 +853,40 @@ bool suffixisImage(const QString &path)
 #endif
 }
 
+QString makeVaultLocalPath(const QString &path, const QString &base)
+{
+    QString basePath = base;
+    if (basePath.isEmpty()) {
+        basePath = VAULT_DECRYPT_DIR_NAME;
+    }
+    return VAULT_BASE_PATH + QDir::separator() + basePath + (path.startsWith('/') ? "" : "/") + path;
+}
 
+bool isVaultFile(const QString &path)
+{
+    bool bVaultFile = false;
+    QString rootPath = makeVaultLocalPath("", "");
+    if (rootPath.back() == "/") {
+        rootPath.chop(1);
+    }
 
+    if (path.contains(rootPath) && path.left(6) != "search") {
+        bVaultFile = true;
+    }
+
+    return bVaultFile;
+
+}
+bool isCanRemove(const QString &path)
+{
+    bool bRet = true;
+    QString trashPath = QDir::homePath() + "/.local/share/Trash";
+    //新增保险箱的判断,回收站判断
+    if (isVaultFile(path) || path.contains(trashPath)) {
+        bRet = false;
+    }
+    return bRet;
+}
 }  // namespace image
 
 }  //namespace utils
