@@ -19,6 +19,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #include "unionimage.h"
+#include "application.h"
 #include <FreeImage.h>
 
 #include <QObject>
@@ -35,6 +36,7 @@
 #include <QtSvg/QSvgRenderer>
 #include <QMimeDatabase>
 
+#include <DSysInfo>
 
 #define SAVE_QUAITY_VALUE 100
 
@@ -177,12 +179,20 @@ public:
                       << "NEF" ;
         //pic（多张图片） pcx不支持旋转
         m_canSave << "BMP" << "JPG" << "JPEG"  << "JPS" << "JPE" << "PNG"
-                  << "PGM" << "PPM" << "PNM" << "WBMP" << "WEBP"
-                  << "SVG" << "TGA" << "XPM" << "ICO"
+                  << "PGM" << "PPM" << "PNM"
+                  << "TGA" << "XPM" << "ICO"
                   << "JNG"
-//                  << "JP2"
-//                  << "PCD"
-                  << "RAS";
+//                << "SVG" //svg不再支持旋转
+//                << "JP2"
+//                << "PCD"
+                  << "RAS"
+                  << "WBMP";
+        Dtk::Core::DSysInfo::UosEdition edition =  Dtk::Core::DSysInfo::uosEditionType();
+        bool isEuler =  Dtk::Core::DSysInfo::UosEuler == edition || Dtk::Core::DSysInfo::UosEnterpriseC == edition;
+        if (!isEuler) {
+            m_canSave <<   "WEBP";
+        }
+        ;
         m_qtrotate << "ICNS" << "JPG" << "JPEG";
     }
     ~UnionImage_Private()
@@ -284,7 +294,13 @@ UNIONIMAGESHARED_EXPORT QString size2Human(const qlonglong bytes)
             return vs + " MB";
         }
     } else {
-        return QString::number(bytes);
+        //修改了当超过一个G的图片,应该用G返回,不应该返回一堆数字,bug68094
+        QString vs = QString::number(static_cast<double>(bytes) / kb / kb / kb, 'f', 1);
+        if (qCeil(vs.toDouble()) == qFloor(vs.toDouble())) {
+            return QString::number(static_cast<int>(vs.toDouble())) + " GB";
+        } else {
+            return vs + " GB";
+        }
     }
 }
 
@@ -641,7 +657,7 @@ UNIONIMAGESHARED_EXPORT bool writeFIBITMAPToFile(FIBITMAP *dib, const QString &p
 //}
 
 QString PrivateDetectImageFormat(const QString &filepath);
-UNIONIMAGESHARED_EXPORT bool loadStaticImageFromFile(const QString &path, QImage &res, QString &errorMsg, const QString &format_bar)
+UNIONIMAGESHARED_EXPORT bool loadStaticImageFromFile(const QString &path, QImage &res, QSize &realSize, QString &errorMsg, const QString &format_bar)
 {
     //20210220真实格式来做判断
     /*判断后缀名是不支持格式，直接返回空的Image*/
@@ -665,10 +681,25 @@ UNIONIMAGESHARED_EXPORT bool loadStaticImageFromFile(const QString &path, QImage
         file_suffix_upper = "TIFF";
     }
     QString file_suffix_lower = file_suffix_upper.toLower();
-    if (f == FIF_RAW || union_image_private.m_qtSupported.contains(file_suffix_upper)) {
+    //解决欧拉版对于raw格式问题判断为PICT的问题
+    bool usingQimage = false;
+    if (!dApp->isEuler()) {
+        usingQimage = (f == FIF_RAW);
+    } else {
+        usingQimage = (f == FIF_RAW || f == FIF_PICT);
+    }
+
+    if (usingQimage || union_image_private.m_qtSupported.contains(file_suffix_upper)) {
         QImageReader reader;
         QImage res_qt;
         reader.setFileName(path);
+        realSize = reader.size();
+
+        //当res参数带信息的时候，认为是加载到与之对应大小的尺寸
+        if (!res.isNull()) {
+            reader.setScaledSize(res.size());
+        }
+
         if (format_bar.isEmpty()) {
             reader.setFormat(file_suffix_lower.toLatin1());
         } else {
@@ -696,6 +727,7 @@ UNIONIMAGESHARED_EXPORT bool loadStaticImageFromFile(const QString &path, QImage
                 }
                 errorMsg = "use old method to load QImage";
                 res = try_res;
+                realSize = res.size();
                 return true;
             }
             errorMsg = "use QImage";
@@ -728,6 +760,7 @@ UNIONIMAGESHARED_EXPORT bool loadStaticImageFromFile(const QString &path, QImage
             }
             FreeImage_Unload(dib);
             errorMsg = "";
+            realSize = res.size();
             return true;
         }
         return false;
@@ -736,100 +769,10 @@ UNIONIMAGESHARED_EXPORT bool loadStaticImageFromFile(const QString &path, QImage
 
 UNIONIMAGESHARED_EXPORT QString detectImageFormat(const QString &path)
 {
-    FREE_IMAGE_FORMAT f = FreeImage_GetFileType(path.toUtf8().data());
-    QString res = union_image_private.m_freeimage_formats.key(f);
-    if (res.isEmpty()) {
-        QFile file(path);
-        if (!file.open(QIODevice::ReadOnly)) {
-            return "";
-        }
-
-        //    const QByteArray data = file.read(1024);
-        const QByteArray data = file.read(64);
-
-        // Check bmp file.
-        if (data.startsWith("BM")) {
-            return "BMP";
-        }
-
-        // Check dds file.
-        if (data.startsWith("DDS")) {
-            return "DDS";
-        }
-
-        // Check gif file.
-        if (data.startsWith("GIF8")) {
-            return "GIF";
-        }
-
-        // Check Max OS icons file.
-        if (data.startsWith("icns")) {
-            return "ICNS";
-        }
-
-        // Check jpeg file.
-        if (data.startsWith("\xff\xd8")) {
-            return "JPG";
-        }
-
-        // Check mng file.
-        if (data.startsWith("\x8a\x4d\x4e\x47\x0d\x0a\x1a\x0a")) {
-            return "MNG";
-        }
-
-        // Check net pbm file (BitMap).
-        if (data.startsWith("P1") || data.startsWith("P4")) {
-            return "PBM";
-        }
-
-        // Check pgm file (GrayMap).
-        if (data.startsWith("P2") || data.startsWith("P5")) {
-            return "PGM";
-        }
-
-        // Check ppm file (PixMap).
-        if (data.startsWith("P3") || data.startsWith("P6")) {
-            return "PPM";
-        }
-
-        // Check png file.
-        if (data.startsWith("\x89PNG\x0d\x0a\x1a\x0a")) {
-            return "PNG";
-        }
-
-        // Check svg file.
-        if (data.indexOf("<svg") > -1) {
-            return "SVG";
-        }
-
-        // TODO(xushaohua): tga file is not supported yet.
-
-        // Check tiff file.
-        if (data.startsWith("MM\x00\x2a") || data.startsWith("II\x2a\x00")) {
-            // big-endian, little-endian.
-            return "TIFF";
-        }
-
-        // TODO(xushaohua): Support wbmp file.
-
-        // Check webp file.
-        if (data.startsWith("RIFFr\x00\x00\x00WEBPVP")) {
-            return "WEBP";
-        }
-
-        // Check xbm file.
-        if (data.indexOf("#define max_width ") > -1 &&
-                data.indexOf("#define max_height ") > -1) {
-            return "XBM";
-        }
-
-        // Check xpm file.
-        if (data.startsWith("/* XPM */")) {
-            return "XPM";
-        }
-        return "";
-    }
-    return res;
+    //用freeimage的格式来做判断
+    QMap<QString, QString> dataMap = getAllMetaData(path);
+    const QString suffix = dataMap.value("FileFormat");
+    return suffix.toUpper();
 }
 
 FREE_IMAGE_FORMAT detectImageFormat_f(const QString &path)
@@ -971,7 +914,8 @@ UNIONIMAGESHARED_EXPORT bool rotateImageFIle(int angel, const QString &path, QSt
     QString format = detectImageFormat(path);
     if (format == "SVG") {
         QImage image_copy;
-        if (!loadStaticImageFromFile(path, image_copy, erroMsg)) {
+        QSize realSize;
+        if (!loadStaticImageFromFile(path, image_copy, realSize, erroMsg)) {
             erroMsg = "rotate load QImage faild, path:" + path + "  ,format:+" + format;
             return false;
         }
