@@ -192,7 +192,9 @@ TEST_F(gtestview, mainwindow)
     QTest::keyClick(m_frameMainWindow, Qt::Key_Down, Qt::ControlModifier, 100);
     QTest::keyClick(m_frameMainWindow, Qt::Key_Down, Qt::ControlModifier, 100);
 
-    QTest::keyClick(m_frameMainWindow, Qt::Key_F11, Qt::NoModifier, 2000);//
+    QTest::keyClick(m_frameMainWindow, Qt::Key_F11, Qt::NoModifier, 1000);//
+    QTest::mouseMove(m_frameMainWindow, QPoint(1000, 1075), 500);
+    QTest::mouseMove(m_frameMainWindow, QPoint(200, 500), 500);
     int index = 0;
     while (index++ < 10)
         QTest::keyClick(m_frameMainWindow, Qt::Key_Plus, Qt::ControlModifier, 10);
@@ -722,7 +724,8 @@ TEST_F(gtestview, unionimage)
     QImage rimg(pppath);
     QImage img2;
     QString errorMsg;
-    loadStaticImageFromFile(m_DDSPath, img2, errorMsg);
+    QSize realSize;
+    loadStaticImageFromFile(m_DDSPath, img2, realSize, errorMsg);
     detectImageFormat(m_DDSPath);
     rotateImage(90, img2);
     QString ddsPath = m_DDSPath;
